"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LeadFormFieldUserInputTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LeadFormFieldUserInputType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LeadFormFieldUserInputType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(0)
        UNKNOWN = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1)
        FULL_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(2)
        GIVEN_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(6)
        FAMILY_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(7)
        EMAIL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(3)
        PHONE_NUMBER = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(4)
        POSTAL_CODE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(5)
        CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(9)
        REGION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(10)
        COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(11)
        WORK_EMAIL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(12)
        COMPANY_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(13)
        WORK_PHONE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(14)
        JOB_TITLE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(15)
        VEHICLE_MODEL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1001
        )
        VEHICLE_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1002)
        PREFERRED_DEALERSHIP = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1003)
        )
        VEHICLE_PURCHASE_TIMELINE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1004)
        )
        VEHICLE_OWNERSHIP = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1005
        )
        VEHICLE_PAYMENT_TYPE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1009)
        )
        VEHICLE_CONDITION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1010
        )
        COMPANY_SIZE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1006)
        ANNUAL_SALES = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1007)
        YEARS_IN_BUSINESS = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1008
        )
        JOB_DEPARTMENT = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1011
        )
        JOB_ROLE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1012)
        EDUCATION_PROGRAM = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1013
        )
        EDUCATION_COURSE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1014
        )
        PRODUCT = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1016)
        SERVICE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1017)
        OFFER = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1018)
        CATEGORY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1019)
        PREFERRED_CONTACT_METHOD = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1020)
        )
        PREFERRED_LOCATION = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1021)
        )
        PREFERRED_CONTACT_TIME = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1022)
        )
        PURCHASE_TIMELINE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1023
        )
        YEARS_OF_EXPERIENCE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1048)
        )
        JOB_INDUSTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1049)
        LEVEL_OF_EDUCATION = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1050)
        )
        PROPERTY_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1024
        )
        REALTOR_HELP_GOAL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1025
        )
        PROPERTY_COMMUNITY = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1026)
        )
        PRICE_RANGE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1027)
        NUMBER_OF_BEDROOMS = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1028)
        )
        FURNISHED_PROPERTY = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1029)
        )
        PETS_ALLOWED_PROPERTY = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1030)
        )
        NEXT_PLANNED_PURCHASE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1031)
        )
        EVENT_SIGNUP_INTEREST = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1033)
        )
        PREFERRED_SHOPPING_PLACES = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1034)
        )
        FAVORITE_BRAND = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1035
        )
        TRANSPORTATION_COMMERCIAL_LICENSE_TYPE = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1036)
        )
        EVENT_BOOKING_INTEREST = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1038)
        )
        DESTINATION_COUNTRY = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1039)
        )
        DESTINATION_CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1040
        )
        DEPARTURE_COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1041
        )
        DEPARTURE_CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1042
        )
        DEPARTURE_DATE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1043
        )
        RETURN_DATE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1044)
        NUMBER_OF_TRAVELERS = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1045)
        )
        TRAVEL_BUDGET = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
            1046
        )
        TRAVEL_ACCOMMODATION = (
            LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1047)
        )
    class LeadFormFieldUserInputType(metaclass=_LeadFormFieldUserInputType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(0)
    UNKNOWN = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1)
    FULL_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(2)
    GIVEN_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(6)
    FAMILY_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(7)
    EMAIL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(3)
    PHONE_NUMBER = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(4)
    POSTAL_CODE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(5)
    CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(9)
    REGION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(10)
    COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(11)
    WORK_EMAIL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(12)
    COMPANY_NAME = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(13)
    WORK_PHONE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(14)
    JOB_TITLE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(15)
    VEHICLE_MODEL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1001)
    VEHICLE_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1002)
    PREFERRED_DEALERSHIP = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1003
    )
    VEHICLE_PURCHASE_TIMELINE = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1004)
    )
    VEHICLE_OWNERSHIP = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1005
    )
    VEHICLE_PAYMENT_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1009
    )
    VEHICLE_CONDITION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1010
    )
    COMPANY_SIZE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1006)
    ANNUAL_SALES = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1007)
    YEARS_IN_BUSINESS = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1008
    )
    JOB_DEPARTMENT = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1011)
    JOB_ROLE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1012)
    EDUCATION_PROGRAM = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1013
    )
    EDUCATION_COURSE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1014)
    PRODUCT = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1016)
    SERVICE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1017)
    OFFER = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1018)
    CATEGORY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1019)
    PREFERRED_CONTACT_METHOD = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1020)
    )
    PREFERRED_LOCATION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1021
    )
    PREFERRED_CONTACT_TIME = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1022)
    )
    PURCHASE_TIMELINE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1023
    )
    YEARS_OF_EXPERIENCE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1048
    )
    JOB_INDUSTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1049)
    LEVEL_OF_EDUCATION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1050
    )
    PROPERTY_TYPE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1024)
    REALTOR_HELP_GOAL = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1025
    )
    PROPERTY_COMMUNITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1026
    )
    PRICE_RANGE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1027)
    NUMBER_OF_BEDROOMS = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1028
    )
    FURNISHED_PROPERTY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1029
    )
    PETS_ALLOWED_PROPERTY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1030
    )
    NEXT_PLANNED_PURCHASE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1031
    )
    EVENT_SIGNUP_INTEREST = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1033
    )
    PREFERRED_SHOPPING_PLACES = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1034)
    )
    FAVORITE_BRAND = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1035)
    TRANSPORTATION_COMMERCIAL_LICENSE_TYPE = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1036)
    )
    EVENT_BOOKING_INTEREST = (
        LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1038)
    )
    DESTINATION_COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1039
    )
    DESTINATION_CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1040)
    DEPARTURE_COUNTRY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1041
    )
    DEPARTURE_CITY = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1042)
    DEPARTURE_DATE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1043)
    RETURN_DATE = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1044)
    NUMBER_OF_TRAVELERS = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1045
    )
    TRAVEL_BUDGET = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(1046)
    TRAVEL_ACCOMMODATION = LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V(
        1047
    )
    def __init__(
        self,
    ) -> None: ...

global___LeadFormFieldUserInputTypeEnum = LeadFormFieldUserInputTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.shared_criterion_pb2
import grpc

from .shared_criterion_service_pb2 import *

class SharedCriterionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetSharedCriterion(
        self,
        request: global___GetSharedCriterionRequest,
    ) -> google.ads.google_ads.v6.proto.resources.shared_criterion_pb2.SharedCriterion: ...
    def MutateSharedCriteria(
        self,
        request: global___MutateSharedCriteriaRequest,
    ) -> global___MutateSharedCriteriaResponse: ...

class SharedCriterionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetSharedCriterion(
        self,
        request: global___GetSharedCriterionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.shared_criterion_pb2.SharedCriterion: ...
    @abc.abstractmethod
    def MutateSharedCriteria(
        self,
        request: global___MutateSharedCriteriaRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateSharedCriteriaResponse: ...

def add_SharedCriterionServiceServicer_to_server(
    servicer: SharedCriterionServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.customer_manager_link_pb2
import grpc

from .customer_manager_link_service_pb2 import *

class CustomerManagerLinkServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerManagerLink(
        self,
        request: global___GetCustomerManagerLinkRequest,
    ) -> google.ads.google_ads.v6.proto.resources.customer_manager_link_pb2.CustomerManagerLink: ...
    def MutateCustomerManagerLink(
        self,
        request: global___MutateCustomerManagerLinkRequest,
    ) -> global___MutateCustomerManagerLinkResponse: ...
    def MoveManagerLink(
        self,
        request: global___MoveManagerLinkRequest,
    ) -> global___MoveManagerLinkResponse: ...

class CustomerManagerLinkServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerManagerLink(
        self,
        request: global___GetCustomerManagerLinkRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.customer_manager_link_pb2.CustomerManagerLink: ...
    @abc.abstractmethod
    def MutateCustomerManagerLink(
        self,
        request: global___MutateCustomerManagerLinkRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerManagerLinkResponse: ...
    @abc.abstractmethod
    def MoveManagerLink(
        self,
        request: global___MoveManagerLinkRequest,
        context: grpc.ServicerContext,
    ) -> global___MoveManagerLinkResponse: ...

def add_CustomerManagerLinkServiceServicer_to_server(
    servicer: CustomerManagerLinkServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_group_bid_modifier_pb2
import grpc

from .ad_group_bid_modifier_service_pb2 import *

class AdGroupBidModifierServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupBidModifier(
        self,
        request: global___GetAdGroupBidModifierRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_bid_modifier_pb2.AdGroupBidModifier: ...
    def MutateAdGroupBidModifiers(
        self,
        request: global___MutateAdGroupBidModifiersRequest,
    ) -> global___MutateAdGroupBidModifiersResponse: ...

class AdGroupBidModifierServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupBidModifier(
        self,
        request: global___GetAdGroupBidModifierRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_bid_modifier_pb2.AdGroupBidModifier: ...
    @abc.abstractmethod
    def MutateAdGroupBidModifiers(
        self,
        request: global___MutateAdGroupBidModifiersRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupBidModifiersResponse: ...

def add_AdGroupBidModifierServiceServicer_to_server(
    servicer: AdGroupBidModifierServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.criterion_category_availability_pb2
import google.ads.google_ads.v4.proto.enums.user_interest_taxonomy_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserInterest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    TAXONOMY_TYPE_FIELD_NUMBER: builtins.int
    USER_INTEREST_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    USER_INTEREST_PARENT_FIELD_NUMBER: builtins.int
    LAUNCHED_TO_ALL_FIELD_NUMBER: builtins.int
    AVAILABILITIES_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    taxonomy_type: google.ads.google_ads.v4.proto.enums.user_interest_taxonomy_type_pb2.UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V = (
        ...
    )
    @property
    def user_interest_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def user_interest_parent(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def launched_to_all(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def availabilities(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.criterion_category_availability_pb2.CriterionCategoryAvailability
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        taxonomy_type: google.ads.google_ads.v4.proto.enums.user_interest_taxonomy_type_pb2.UserInterestTaxonomyTypeEnum.UserInterestTaxonomyType.V = ...,
        user_interest_id: typing.Optional[
            google.protobuf.wrappers_pb2.Int64Value
        ] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        user_interest_parent: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        launched_to_all: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
        availabilities: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.criterion_category_availability_pb2.CriterionCategoryAvailability
            ]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "launched_to_all",
            b"launched_to_all",
            "name",
            b"name",
            "user_interest_id",
            b"user_interest_id",
            "user_interest_parent",
            b"user_interest_parent",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "availabilities",
            b"availabilities",
            "launched_to_all",
            b"launched_to_all",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "taxonomy_type",
            b"taxonomy_type",
            "user_interest_id",
            b"user_interest_id",
            "user_interest_parent",
            b"user_interest_parent",
        ],
    ) -> None: ...

global___UserInterest = UserInterest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedMappingCriterionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedMappingCriterionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedMappingCriterionType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(0)
        UNKNOWN = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(1)
        LOCATION_EXTENSION_TARGETING = (
            FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(4)
        )
        DSA_PAGE_FEED = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(3)
    class FeedMappingCriterionType(metaclass=_FeedMappingCriterionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(0)
    UNKNOWN = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(1)
    LOCATION_EXTENSION_TARGETING = (
        FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(4)
    )
    DSA_PAGE_FEED = FeedMappingCriterionTypeEnum.FeedMappingCriterionType.V(3)
    def __init__(
        self,
    ) -> None: ...

global___FeedMappingCriterionTypeEnum = FeedMappingCriterionTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.campaign_feed_pb2
import grpc

from .campaign_feed_service_pb2 import *

class CampaignFeedServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignFeed(
        self,
        request: global___GetCampaignFeedRequest,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_feed_pb2.CampaignFeed: ...
    def MutateCampaignFeeds(
        self,
        request: global___MutateCampaignFeedsRequest,
    ) -> global___MutateCampaignFeedsResponse: ...

class CampaignFeedServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignFeed(
        self,
        request: global___GetCampaignFeedRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.campaign_feed_pb2.CampaignFeed: ...
    @abc.abstractmethod
    def MutateCampaignFeeds(
        self,
        request: global___MutateCampaignFeedsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignFeedsResponse: ...

def add_CampaignFeedServiceServicer_to_server(
    servicer: CampaignFeedServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionActionCategoryEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ConversionActionCategory(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ConversionActionCategory.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ConversionActionCategoryEnum.ConversionActionCategory.V(0)
        UNKNOWN = ConversionActionCategoryEnum.ConversionActionCategory.V(1)
        DEFAULT = ConversionActionCategoryEnum.ConversionActionCategory.V(2)
        PAGE_VIEW = ConversionActionCategoryEnum.ConversionActionCategory.V(3)
        PURCHASE = ConversionActionCategoryEnum.ConversionActionCategory.V(4)
        SIGNUP = ConversionActionCategoryEnum.ConversionActionCategory.V(5)
        LEAD = ConversionActionCategoryEnum.ConversionActionCategory.V(6)
        DOWNLOAD = ConversionActionCategoryEnum.ConversionActionCategory.V(7)
        ADD_TO_CART = ConversionActionCategoryEnum.ConversionActionCategory.V(8)
        BEGIN_CHECKOUT = ConversionActionCategoryEnum.ConversionActionCategory.V(9)
        SUBSCRIBE_PAID = ConversionActionCategoryEnum.ConversionActionCategory.V(10)
        PHONE_CALL_LEAD = ConversionActionCategoryEnum.ConversionActionCategory.V(11)
        IMPORTED_LEAD = ConversionActionCategoryEnum.ConversionActionCategory.V(12)
        SUBMIT_LEAD_FORM = ConversionActionCategoryEnum.ConversionActionCategory.V(13)
        BOOK_APPOINTMENT = ConversionActionCategoryEnum.ConversionActionCategory.V(14)
        REQUEST_QUOTE = ConversionActionCategoryEnum.ConversionActionCategory.V(15)
        GET_DIRECTIONS = ConversionActionCategoryEnum.ConversionActionCategory.V(16)
        OUTBOUND_CLICK = ConversionActionCategoryEnum.ConversionActionCategory.V(17)
        CONTACT = ConversionActionCategoryEnum.ConversionActionCategory.V(18)
        ENGAGEMENT = ConversionActionCategoryEnum.ConversionActionCategory.V(19)
        STORE_VISIT = ConversionActionCategoryEnum.ConversionActionCategory.V(20)
        STORE_SALE = ConversionActionCategoryEnum.ConversionActionCategory.V(21)
    class ConversionActionCategory(metaclass=_ConversionActionCategory):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ConversionActionCategoryEnum.ConversionActionCategory.V(0)
    UNKNOWN = ConversionActionCategoryEnum.ConversionActionCategory.V(1)
    DEFAULT = ConversionActionCategoryEnum.ConversionActionCategory.V(2)
    PAGE_VIEW = ConversionActionCategoryEnum.ConversionActionCategory.V(3)
    PURCHASE = ConversionActionCategoryEnum.ConversionActionCategory.V(4)
    SIGNUP = ConversionActionCategoryEnum.ConversionActionCategory.V(5)
    LEAD = ConversionActionCategoryEnum.ConversionActionCategory.V(6)
    DOWNLOAD = ConversionActionCategoryEnum.ConversionActionCategory.V(7)
    ADD_TO_CART = ConversionActionCategoryEnum.ConversionActionCategory.V(8)
    BEGIN_CHECKOUT = ConversionActionCategoryEnum.ConversionActionCategory.V(9)
    SUBSCRIBE_PAID = ConversionActionCategoryEnum.ConversionActionCategory.V(10)
    PHONE_CALL_LEAD = ConversionActionCategoryEnum.ConversionActionCategory.V(11)
    IMPORTED_LEAD = ConversionActionCategoryEnum.ConversionActionCategory.V(12)
    SUBMIT_LEAD_FORM = ConversionActionCategoryEnum.ConversionActionCategory.V(13)
    BOOK_APPOINTMENT = ConversionActionCategoryEnum.ConversionActionCategory.V(14)
    REQUEST_QUOTE = ConversionActionCategoryEnum.ConversionActionCategory.V(15)
    GET_DIRECTIONS = ConversionActionCategoryEnum.ConversionActionCategory.V(16)
    OUTBOUND_CLICK = ConversionActionCategoryEnum.ConversionActionCategory.V(17)
    CONTACT = ConversionActionCategoryEnum.ConversionActionCategory.V(18)
    ENGAGEMENT = ConversionActionCategoryEnum.ConversionActionCategory.V(19)
    STORE_VISIT = ConversionActionCategoryEnum.ConversionActionCategory.V(20)
    STORE_SALE = ConversionActionCategoryEnum.ConversionActionCategory.V(21)
    def __init__(
        self,
    ) -> None: ...

global___ConversionActionCategoryEnum = ConversionActionCategoryEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccessRoleEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccessRole(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AccessRole.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccessRoleEnum.AccessRole.V(0)
        UNKNOWN = AccessRoleEnum.AccessRole.V(1)
        ADMIN = AccessRoleEnum.AccessRole.V(2)
        STANDARD = AccessRoleEnum.AccessRole.V(3)
        READ_ONLY = AccessRoleEnum.AccessRole.V(4)
        EMAIL_ONLY = AccessRoleEnum.AccessRole.V(5)
    class AccessRole(metaclass=_AccessRole):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccessRoleEnum.AccessRole.V(0)
    UNKNOWN = AccessRoleEnum.AccessRole.V(1)
    ADMIN = AccessRoleEnum.AccessRole.V(2)
    STANDARD = AccessRoleEnum.AccessRole.V(3)
    READ_ONLY = AccessRoleEnum.AccessRole.V(4)
    EMAIL_ONLY = AccessRoleEnum.AccessRole.V(5)
    def __init__(
        self,
    ) -> None: ...

global___AccessRoleEnum = AccessRoleEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.keyword_match_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanCampaignKeyword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    MATCH_TYPE_FIELD_NUMBER: builtins.int
    NEGATIVE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    keyword_plan_campaign: typing.Text = ...
    id: builtins.int = ...
    text: typing.Text = ...
    match_type: google.ads.google_ads.v6.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = (
        ...
    )
    negative: builtins.bool = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        keyword_plan_campaign: typing.Text = ...,
        id: builtins.int = ...,
        text: typing.Text = ...,
        match_type: google.ads.google_ads.v6.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = ...,
        negative: builtins.bool = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "_negative",
            b"_negative",
            "_text",
            b"_text",
            "id",
            b"id",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "negative",
            b"negative",
            "text",
            b"text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "_negative",
            b"_negative",
            "_text",
            b"_text",
            "id",
            b"id",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "match_type",
            b"match_type",
            "negative",
            b"negative",
            "resource_name",
            b"resource_name",
            "text",
            b"text",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_keyword_plan_campaign", b"_keyword_plan_campaign"
        ],
    ) -> typing_extensions.Literal["keyword_plan_campaign"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_negative", b"_negative"]
    ) -> typing_extensions.Literal["negative"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...

global___KeywordPlanCampaignKeyword = KeywordPlanCampaignKeyword



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupCriterionLabel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    ad_group_criterion: typing.Text = ...
    label: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        ad_group_criterion: typing.Text = ...,
        label: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_criterion",
            b"_ad_group_criterion",
            "_label",
            b"_label",
            "ad_group_criterion",
            b"ad_group_criterion",
            "label",
            b"label",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_criterion",
            b"_ad_group_criterion",
            "_label",
            b"_label",
            "ad_group_criterion",
            b"ad_group_criterion",
            "label",
            b"label",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_ad_group_criterion", b"_ad_group_criterion"
        ],
    ) -> typing_extensions.Literal["ad_group_criterion"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_label", b"_label"]
    ) -> typing_extensions.Literal["label"]: ...

global___AdGroupCriterionLabel = AdGroupCriterionLabel



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetPerformanceLabelEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetPerformanceLabel(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AssetPerformanceLabel.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(0)
        UNKNOWN = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(1)
        PENDING = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(2)
        LEARNING = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(3)
        LOW = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(4)
        GOOD = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(5)
        BEST = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(6)
    class AssetPerformanceLabel(metaclass=_AssetPerformanceLabel):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(0)
    UNKNOWN = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(1)
    PENDING = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(2)
    LEARNING = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(3)
    LOW = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(4)
    GOOD = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(5)
    BEST = AssetPerformanceLabelEnum.AssetPerformanceLabel.V(6)
    def __init__(
        self,
    ) -> None: ...

global___AssetPerformanceLabelEnum = AssetPerformanceLabelEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.keyword_plan_campaign_keyword_pb2
import grpc

from .keyword_plan_campaign_keyword_service_pb2 import *

class KeywordPlanCampaignKeywordServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetKeywordPlanCampaignKeyword(
        self,
        request: global___GetKeywordPlanCampaignKeywordRequest,
    ) -> google.ads.google_ads.v5.proto.resources.keyword_plan_campaign_keyword_pb2.KeywordPlanCampaignKeyword: ...
    def MutateKeywordPlanCampaignKeywords(
        self,
        request: global___MutateKeywordPlanCampaignKeywordsRequest,
    ) -> global___MutateKeywordPlanCampaignKeywordsResponse: ...

class KeywordPlanCampaignKeywordServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetKeywordPlanCampaignKeyword(
        self,
        request: global___GetKeywordPlanCampaignKeywordRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.keyword_plan_campaign_keyword_pb2.KeywordPlanCampaignKeyword: ...
    @abc.abstractmethod
    def MutateKeywordPlanCampaignKeywords(
        self,
        request: global___MutateKeywordPlanCampaignKeywordsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateKeywordPlanCampaignKeywordsResponse: ...

def add_KeywordPlanCampaignKeywordServiceServicer_to_server(
    servicer: KeywordPlanCampaignKeywordServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.campaign_asset_pb2
import grpc

from .campaign_asset_service_pb2 import *

class CampaignAssetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignAsset(
        self,
        request: global___GetCampaignAssetRequest,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_asset_pb2.CampaignAsset: ...
    def MutateCampaignAssets(
        self,
        request: global___MutateCampaignAssetsRequest,
    ) -> global___MutateCampaignAssetsResponse: ...

class CampaignAssetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignAsset(
        self,
        request: global___GetCampaignAssetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_asset_pb2.CampaignAsset: ...
    @abc.abstractmethod
    def MutateCampaignAssets(
        self,
        request: global___MutateCampaignAssetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignAssetsResponse: ...

def add_CampaignAssetServiceServicer_to_server(
    servicer: CampaignAssetServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.feed_item_set_pb2
import grpc

from .feed_item_set_service_pb2 import *

class FeedItemSetServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetFeedItemSet(
        self,
        request: global___GetFeedItemSetRequest,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_set_pb2.FeedItemSet: ...
    def MutateFeedItemSets(
        self,
        request: global___MutateFeedItemSetsRequest,
    ) -> global___MutateFeedItemSetsResponse: ...

class FeedItemSetServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetFeedItemSet(
        self,
        request: global___GetFeedItemSetRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.feed_item_set_pb2.FeedItemSet: ...
    @abc.abstractmethod
    def MutateFeedItemSets(
        self,
        request: global___MutateFeedItemSetsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateFeedItemSetsResponse: ...

def add_FeedItemSetServiceServicer_to_server(
    servicer: FeedItemSetServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.billing_setup_status_pb2
import google.ads.google_ads.v4.proto.enums.time_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BillingSetup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class PaymentsAccountInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        PAYMENTS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
        PAYMENTS_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
        PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
        PAYMENTS_PROFILE_NAME_FIELD_NUMBER: builtins.int
        SECONDARY_PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
        @property
        def payments_account_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def payments_account_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def payments_profile_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def payments_profile_name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def secondary_payments_profile_id(
            self,
        ) -> google.protobuf.wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            payments_account_id: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            payments_account_name: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            payments_profile_id: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            payments_profile_name: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            secondary_payments_profile_id: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "payments_account_id",
                b"payments_account_id",
                "payments_account_name",
                b"payments_account_name",
                "payments_profile_id",
                b"payments_profile_id",
                "payments_profile_name",
                b"payments_profile_name",
                "secondary_payments_profile_id",
                b"secondary_payments_profile_id",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "payments_account_id",
                b"payments_account_id",
                "payments_account_name",
                b"payments_account_name",
                "payments_profile_id",
                b"payments_profile_id",
                "payments_profile_name",
                b"payments_profile_name",
                "secondary_payments_profile_id",
                b"secondary_payments_profile_id",
            ],
        ) -> None: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PAYMENTS_ACCOUNT_FIELD_NUMBER: builtins.int
    PAYMENTS_ACCOUNT_INFO_FIELD_NUMBER: builtins.int
    START_DATE_TIME_FIELD_NUMBER: builtins.int
    START_TIME_TYPE_FIELD_NUMBER: builtins.int
    END_DATE_TIME_FIELD_NUMBER: builtins.int
    END_TIME_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    status: google.ads.google_ads.v4.proto.enums.billing_setup_status_pb2.BillingSetupStatusEnum.BillingSetupStatus.V = (
        ...
    )
    start_time_type: google.ads.google_ads.v4.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    end_time_type: google.ads.google_ads.v4.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def payments_account(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def payments_account_info(self) -> global___BillingSetup.PaymentsAccountInfo: ...
    @property
    def start_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def end_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        status: google.ads.google_ads.v4.proto.enums.billing_setup_status_pb2.BillingSetupStatusEnum.BillingSetupStatus.V = ...,
        payments_account: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        payments_account_info: typing.Optional[
            global___BillingSetup.PaymentsAccountInfo
        ] = ...,
        start_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        start_time_type: google.ads.google_ads.v4.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
        end_date_time: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        end_time_type: google.ads.google_ads.v4.proto.enums.time_type_pb2.TimeTypeEnum.TimeType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "end_date_time",
            b"end_date_time",
            "end_time",
            b"end_time",
            "end_time_type",
            b"end_time_type",
            "id",
            b"id",
            "payments_account",
            b"payments_account",
            "payments_account_info",
            b"payments_account_info",
            "start_date_time",
            b"start_date_time",
            "start_time",
            b"start_time",
            "start_time_type",
            b"start_time_type",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "end_date_time",
            b"end_date_time",
            "end_time",
            b"end_time",
            "end_time_type",
            b"end_time_type",
            "id",
            b"id",
            "payments_account",
            b"payments_account",
            "payments_account_info",
            b"payments_account_info",
            "resource_name",
            b"resource_name",
            "start_date_time",
            b"start_date_time",
            "start_time",
            b"start_time",
            "start_time_type",
            b"start_time_type",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["end_time", b"end_time"]
    ) -> typing_extensions.Literal["end_date_time", "end_time_type"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["start_time", b"start_time"]
    ) -> typing_extensions.Literal["start_date_time", "start_time_type"]: ...

global___BillingSetup = BillingSetup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ContextErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ContextError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ContextError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ContextErrorEnum.ContextError.V(0)
        UNKNOWN = ContextErrorEnum.ContextError.V(1)
        OPERATION_NOT_PERMITTED_FOR_CONTEXT = ContextErrorEnum.ContextError.V(2)
        OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = ContextErrorEnum.ContextError.V(
            3
        )
    class ContextError(metaclass=_ContextError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ContextErrorEnum.ContextError.V(0)
    UNKNOWN = ContextErrorEnum.ContextError.V(1)
    OPERATION_NOT_PERMITTED_FOR_CONTEXT = ContextErrorEnum.ContextError.V(2)
    OPERATION_NOT_PERMITTED_FOR_REMOVED_RESOURCE = ContextErrorEnum.ContextError.V(3)
    def __init__(
        self,
    ) -> None: ...

global___ContextErrorEnum = ContextErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemQualityDisapprovalReasonEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemQualityDisapprovalReason(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedItemQualityDisapprovalReason.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(0)
        )
        UNKNOWN = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(1)
        )
        PRICE_TABLE_REPETITIVE_HEADERS = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(2)
        )
        PRICE_TABLE_REPETITIVE_DESCRIPTION = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(3)
        )
        PRICE_TABLE_INCONSISTENT_ROWS = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(4)
        )
        PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(5)
        )
        PRICE_UNSUPPORTED_LANGUAGE = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(6)
        )
        PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(7)
        )
        PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(8)
        )
        PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(9)
        )
        PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(10)
        )
        PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(11)
        )
        PRICE_TABLE_ROW_UNRATEABLE = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(12)
        )
        PRICE_TABLE_ROW_PRICE_INVALID = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(13)
        )
        PRICE_TABLE_ROW_URL_INVALID = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(14)
        )
        PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(15)
        )
        STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(16)
        )
        STRUCTURED_SNIPPETS_REPEATED_VALUES = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(17)
        )
        STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(18)
        )
        STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = (
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(19)
        )
    class FeedItemQualityDisapprovalReason(metaclass=_FeedItemQualityDisapprovalReason):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(0)
    )
    UNKNOWN = FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(1)
    PRICE_TABLE_REPETITIVE_HEADERS = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(2)
    )
    PRICE_TABLE_REPETITIVE_DESCRIPTION = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(3)
    )
    PRICE_TABLE_INCONSISTENT_ROWS = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(4)
    )
    PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(5)
    )
    PRICE_UNSUPPORTED_LANGUAGE = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(6)
    )
    PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(7)
    )
    PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(8)
    )
    PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(9)
    )
    PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(10)
    )
    PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(11)
    )
    PRICE_TABLE_ROW_UNRATEABLE = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(12)
    )
    PRICE_TABLE_ROW_PRICE_INVALID = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(13)
    )
    PRICE_TABLE_ROW_URL_INVALID = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(14)
    )
    PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(15)
    )
    STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(16)
    )
    STRUCTURED_SNIPPETS_REPEATED_VALUES = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(17)
    )
    STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(18)
    )
    STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = (
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason.V(19)
    )
    def __init__(
        self,
    ) -> None: ...

global___FeedItemQualityDisapprovalReasonEnum = FeedItemQualityDisapprovalReasonEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.campaign_criterion_pb2
import grpc

from .campaign_criterion_service_pb2 import *

class CampaignCriterionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignCriterion(
        self,
        request: global___GetCampaignCriterionRequest,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_criterion_pb2.CampaignCriterion: ...
    def MutateCampaignCriteria(
        self,
        request: global___MutateCampaignCriteriaRequest,
    ) -> global___MutateCampaignCriteriaResponse: ...

class CampaignCriterionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignCriterion(
        self,
        request: global___GetCampaignCriterionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_criterion_pb2.CampaignCriterion: ...
    @abc.abstractmethod
    def MutateCampaignCriteria(
        self,
        request: global___MutateCampaignCriteriaRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignCriteriaResponse: ...

def add_CampaignCriterionServiceServicer_to_server(
    servicer: CampaignCriterionServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class YoutubeVideoRegistrationErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _YoutubeVideoRegistrationError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            YoutubeVideoRegistrationError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(
            0
        )
        UNKNOWN = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(1)
        VIDEO_NOT_FOUND = (
            YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(2)
        )
        VIDEO_NOT_ACCESSIBLE = (
            YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(3)
        )
        VIDEO_NOT_ELIGIBLE = (
            YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(4)
        )
    class YoutubeVideoRegistrationError(metaclass=_YoutubeVideoRegistrationError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(0)
    UNKNOWN = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(1)
    VIDEO_NOT_FOUND = YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(
        2
    )
    VIDEO_NOT_ACCESSIBLE = (
        YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(3)
    )
    VIDEO_NOT_ELIGIBLE = (
        YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationError.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___YoutubeVideoRegistrationErrorEnum = YoutubeVideoRegistrationErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.customer_user_access_pb2
import grpc

from .customer_user_access_service_pb2 import *

class CustomerUserAccessServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerUserAccess(
        self,
        request: global___GetCustomerUserAccessRequest,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_pb2.CustomerUserAccess: ...
    def MutateCustomerUserAccess(
        self,
        request: global___MutateCustomerUserAccessRequest,
    ) -> global___MutateCustomerUserAccessResponse: ...

class CustomerUserAccessServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerUserAccess(
        self,
        request: global___GetCustomerUserAccessRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_pb2.CustomerUserAccess: ...
    @abc.abstractmethod
    def MutateCustomerUserAccess(
        self,
        request: global___MutateCustomerUserAccessRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerUserAccessResponse: ...

def add_CustomerUserAccessServiceServicer_to_server(
    servicer: CustomerUserAccessServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TargetingDimensionEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TargetingDimension(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            TargetingDimension.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TargetingDimensionEnum.TargetingDimension.V(0)
        UNKNOWN = TargetingDimensionEnum.TargetingDimension.V(1)
        KEYWORD = TargetingDimensionEnum.TargetingDimension.V(2)
        AUDIENCE = TargetingDimensionEnum.TargetingDimension.V(3)
        TOPIC = TargetingDimensionEnum.TargetingDimension.V(4)
        GENDER = TargetingDimensionEnum.TargetingDimension.V(5)
        AGE_RANGE = TargetingDimensionEnum.TargetingDimension.V(6)
        PLACEMENT = TargetingDimensionEnum.TargetingDimension.V(7)
        PARENTAL_STATUS = TargetingDimensionEnum.TargetingDimension.V(8)
        INCOME_RANGE = TargetingDimensionEnum.TargetingDimension.V(9)
    class TargetingDimension(metaclass=_TargetingDimension):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TargetingDimensionEnum.TargetingDimension.V(0)
    UNKNOWN = TargetingDimensionEnum.TargetingDimension.V(1)
    KEYWORD = TargetingDimensionEnum.TargetingDimension.V(2)
    AUDIENCE = TargetingDimensionEnum.TargetingDimension.V(3)
    TOPIC = TargetingDimensionEnum.TargetingDimension.V(4)
    GENDER = TargetingDimensionEnum.TargetingDimension.V(5)
    AGE_RANGE = TargetingDimensionEnum.TargetingDimension.V(6)
    PLACEMENT = TargetingDimensionEnum.TargetingDimension.V(7)
    PARENTAL_STATUS = TargetingDimensionEnum.TargetingDimension.V(8)
    INCOME_RANGE = TargetingDimensionEnum.TargetingDimension.V(9)
    def __init__(
        self,
    ) -> None: ...

global___TargetingDimensionEnum = TargetingDimensionEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerClientLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomerClientLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomerClientLinkError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(0)
        UNKNOWN = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(1)
        CLIENT_ALREADY_INVITED_BY_THIS_MANAGER = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(2)
        )
        CLIENT_ALREADY_MANAGED_IN_HIERARCHY = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(3)
        )
        CYCLIC_LINK_NOT_ALLOWED = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(
            4
        )
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(5)
        )
        CLIENT_HAS_TOO_MANY_INVITATIONS = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(6)
        )
        CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(7)
        )
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(8)
        )
        CLIENT_HAS_TOO_MANY_MANAGERS = (
            CustomerClientLinkErrorEnum.CustomerClientLinkError.V(9)
        )
    class CustomerClientLinkError(metaclass=_CustomerClientLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(0)
    UNKNOWN = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(1)
    CLIENT_ALREADY_INVITED_BY_THIS_MANAGER = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(2)
    )
    CLIENT_ALREADY_MANAGED_IN_HIERARCHY = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(3)
    )
    CYCLIC_LINK_NOT_ALLOWED = CustomerClientLinkErrorEnum.CustomerClientLinkError.V(4)
    CUSTOMER_HAS_TOO_MANY_ACCOUNTS = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(5)
    )
    CLIENT_HAS_TOO_MANY_INVITATIONS = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(6)
    )
    CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(7)
    )
    CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(8)
    )
    CLIENT_HAS_TOO_MANY_MANAGERS = (
        CustomerClientLinkErrorEnum.CustomerClientLinkError.V(9)
    )
    def __init__(
        self,
    ) -> None: ...

global___CustomerClientLinkErrorEnum = CustomerClientLinkErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.criteria_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignBidModifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    CRITERION_ID_FIELD_NUMBER: builtins.int
    BID_MODIFIER_FIELD_NUMBER: builtins.int
    INTERACTION_TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    campaign: typing.Text = ...
    criterion_id: builtins.int = ...
    bid_modifier: builtins.float = ...
    @property
    def interaction_type(
        self,
    ) -> google.ads.google_ads.v5.proto.common.criteria_pb2.InteractionTypeInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        campaign: typing.Text = ...,
        criterion_id: builtins.int = ...,
        bid_modifier: builtins.float = ...,
        interaction_type: typing.Optional[
            google.ads.google_ads.v5.proto.common.criteria_pb2.InteractionTypeInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_campaign",
            b"_campaign",
            "_criterion_id",
            b"_criterion_id",
            "bid_modifier",
            b"bid_modifier",
            "campaign",
            b"campaign",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "interaction_type",
            b"interaction_type",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_campaign",
            b"_campaign",
            "_criterion_id",
            b"_criterion_id",
            "bid_modifier",
            b"bid_modifier",
            "campaign",
            b"campaign",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "interaction_type",
            b"interaction_type",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_bid_modifier", b"_bid_modifier"]
    ) -> typing_extensions.Literal["bid_modifier"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_campaign", b"_campaign"]
    ) -> typing_extensions.Literal["campaign"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_criterion_id", b"_criterion_id"]
    ) -> typing_extensions.Literal["criterion_id"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["criterion", b"criterion"]
    ) -> typing_extensions.Literal["interaction_type"]: ...

global___CampaignBidModifier = CampaignBidModifier



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CallPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CallPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CallPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CallPlaceholderFieldEnum.CallPlaceholderField.V(0)
        UNKNOWN = CallPlaceholderFieldEnum.CallPlaceholderField.V(1)
        PHONE_NUMBER = CallPlaceholderFieldEnum.CallPlaceholderField.V(2)
        COUNTRY_CODE = CallPlaceholderFieldEnum.CallPlaceholderField.V(3)
        TRACKED = CallPlaceholderFieldEnum.CallPlaceholderField.V(4)
        CONVERSION_TYPE_ID = CallPlaceholderFieldEnum.CallPlaceholderField.V(5)
        CONVERSION_REPORTING_STATE = CallPlaceholderFieldEnum.CallPlaceholderField.V(6)
    class CallPlaceholderField(metaclass=_CallPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CallPlaceholderFieldEnum.CallPlaceholderField.V(0)
    UNKNOWN = CallPlaceholderFieldEnum.CallPlaceholderField.V(1)
    PHONE_NUMBER = CallPlaceholderFieldEnum.CallPlaceholderField.V(2)
    COUNTRY_CODE = CallPlaceholderFieldEnum.CallPlaceholderField.V(3)
    TRACKED = CallPlaceholderFieldEnum.CallPlaceholderField.V(4)
    CONVERSION_TYPE_ID = CallPlaceholderFieldEnum.CallPlaceholderField.V(5)
    CONVERSION_REPORTING_STATE = CallPlaceholderFieldEnum.CallPlaceholderField.V(6)
    def __init__(
        self,
    ) -> None: ...

global___CallPlaceholderFieldEnum = CallPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AssetFieldTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AssetFieldType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AssetFieldType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AssetFieldTypeEnum.AssetFieldType.V(0)
        UNKNOWN = AssetFieldTypeEnum.AssetFieldType.V(1)
        HEADLINE = AssetFieldTypeEnum.AssetFieldType.V(2)
        DESCRIPTION = AssetFieldTypeEnum.AssetFieldType.V(3)
        MANDATORY_AD_TEXT = AssetFieldTypeEnum.AssetFieldType.V(4)
        MARKETING_IMAGE = AssetFieldTypeEnum.AssetFieldType.V(5)
        MEDIA_BUNDLE = AssetFieldTypeEnum.AssetFieldType.V(6)
        YOUTUBE_VIDEO = AssetFieldTypeEnum.AssetFieldType.V(7)
    class AssetFieldType(metaclass=_AssetFieldType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AssetFieldTypeEnum.AssetFieldType.V(0)
    UNKNOWN = AssetFieldTypeEnum.AssetFieldType.V(1)
    HEADLINE = AssetFieldTypeEnum.AssetFieldType.V(2)
    DESCRIPTION = AssetFieldTypeEnum.AssetFieldType.V(3)
    MANDATORY_AD_TEXT = AssetFieldTypeEnum.AssetFieldType.V(4)
    MARKETING_IMAGE = AssetFieldTypeEnum.AssetFieldType.V(5)
    MEDIA_BUNDLE = AssetFieldTypeEnum.AssetFieldType.V(6)
    YOUTUBE_VIDEO = AssetFieldTypeEnum.AssetFieldType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___AssetFieldTypeEnum = AssetFieldTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.customer_negative_criterion_pb2
import grpc

from .customer_negative_criterion_service_pb2 import *

class CustomerNegativeCriterionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCustomerNegativeCriterion(
        self,
        request: global___GetCustomerNegativeCriterionRequest,
    ) -> google.ads.google_ads.v4.proto.resources.customer_negative_criterion_pb2.CustomerNegativeCriterion: ...
    def MutateCustomerNegativeCriteria(
        self,
        request: global___MutateCustomerNegativeCriteriaRequest,
    ) -> global___MutateCustomerNegativeCriteriaResponse: ...

class CustomerNegativeCriterionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCustomerNegativeCriterion(
        self,
        request: global___GetCustomerNegativeCriterionRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.customer_negative_criterion_pb2.CustomerNegativeCriterion: ...
    @abc.abstractmethod
    def MutateCustomerNegativeCriteria(
        self,
        request: global___MutateCustomerNegativeCriteriaRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCustomerNegativeCriteriaResponse: ...

def add_CustomerNegativeCriterionServiceServicer_to_server(
    servicer: CustomerNegativeCriterionServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.tag_snippet_pb2
import google.ads.google_ads.v5.proto.enums.attribution_model_pb2
import google.ads.google_ads.v5.proto.enums.conversion_action_category_pb2
import google.ads.google_ads.v5.proto.enums.conversion_action_counting_type_pb2
import google.ads.google_ads.v5.proto.enums.conversion_action_status_pb2
import google.ads.google_ads.v5.proto.enums.conversion_action_type_pb2
import google.ads.google_ads.v5.proto.enums.data_driven_model_status_pb2
import google.ads.google_ads.v5.proto.enums.mobile_app_vendor_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConversionAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class AttributionModelSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ATTRIBUTION_MODEL_FIELD_NUMBER: builtins.int
        DATA_DRIVEN_MODEL_STATUS_FIELD_NUMBER: builtins.int
        attribution_model: google.ads.google_ads.v5.proto.enums.attribution_model_pb2.AttributionModelEnum.AttributionModel.V = (
            ...
        )
        data_driven_model_status: google.ads.google_ads.v5.proto.enums.data_driven_model_status_pb2.DataDrivenModelStatusEnum.DataDrivenModelStatus.V = (
            ...
        )
        def __init__(
            self,
            *,
            attribution_model: google.ads.google_ads.v5.proto.enums.attribution_model_pb2.AttributionModelEnum.AttributionModel.V = ...,
            data_driven_model_status: google.ads.google_ads.v5.proto.enums.data_driven_model_status_pb2.DataDrivenModelStatusEnum.DataDrivenModelStatus.V = ...,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "attribution_model",
                b"attribution_model",
                "data_driven_model_status",
                b"data_driven_model_status",
            ],
        ) -> None: ...
    class ValueSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DEFAULT_VALUE_FIELD_NUMBER: builtins.int
        DEFAULT_CURRENCY_CODE_FIELD_NUMBER: builtins.int
        ALWAYS_USE_DEFAULT_VALUE_FIELD_NUMBER: builtins.int
        default_value: builtins.float = ...
        default_currency_code: typing.Text = ...
        always_use_default_value: builtins.bool = ...
        def __init__(
            self,
            *,
            default_value: builtins.float = ...,
            default_currency_code: typing.Text = ...,
            always_use_default_value: builtins.bool = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_always_use_default_value",
                b"_always_use_default_value",
                "_default_currency_code",
                b"_default_currency_code",
                "_default_value",
                b"_default_value",
                "always_use_default_value",
                b"always_use_default_value",
                "default_currency_code",
                b"default_currency_code",
                "default_value",
                b"default_value",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_always_use_default_value",
                b"_always_use_default_value",
                "_default_currency_code",
                b"_default_currency_code",
                "_default_value",
                b"_default_value",
                "always_use_default_value",
                b"always_use_default_value",
                "default_currency_code",
                b"default_currency_code",
                "default_value",
                b"default_value",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_always_use_default_value", b"_always_use_default_value"
            ],
        ) -> typing_extensions.Literal["always_use_default_value"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "_default_currency_code", b"_default_currency_code"
            ],
        ) -> typing_extensions.Literal["default_currency_code"]: ...
        @typing.overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal["_default_value", b"_default_value"],
        ) -> typing_extensions.Literal["default_value"]: ...
    class ThirdPartyAppAnalyticsSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        EVENT_NAME_FIELD_NUMBER: builtins.int
        event_name: typing.Text = ...
        def __init__(
            self,
            *,
            event_name: typing.Text = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_event_name", b"_event_name", "event_name", b"event_name"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_event_name", b"_event_name", "event_name", b"event_name"
            ],
        ) -> None: ...
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_event_name", b"_event_name"]
        ) -> typing_extensions.Literal["event_name"]: ...
    class FirebaseSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        EVENT_NAME_FIELD_NUMBER: builtins.int
        PROJECT_ID_FIELD_NUMBER: builtins.int
        event_name: typing.Text = ...
        project_id: typing.Text = ...
        def __init__(
            self,
            *,
            event_name: typing.Text = ...,
            project_id: typing.Text = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "_event_name",
                b"_event_name",
                "_project_id",
                b"_project_id",
                "event_name",
                b"event_name",
                "project_id",
                b"project_id",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "_event_name",
                b"_event_name",
                "_project_id",
                b"_project_id",
                "event_name",
                b"event_name",
                "project_id",
                b"project_id",
            ],
        ) -> None: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_event_name", b"_event_name"]
        ) -> typing_extensions.Literal["event_name"]: ...
        @typing.overload
        def WhichOneof(
            self, oneof_group: typing_extensions.Literal["_project_id", b"_project_id"]
        ) -> typing_extensions.Literal["project_id"]: ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    OWNER_CUSTOMER_FIELD_NUMBER: builtins.int
    INCLUDE_IN_CONVERSIONS_METRIC_FIELD_NUMBER: builtins.int
    CLICK_THROUGH_LOOKBACK_WINDOW_DAYS_FIELD_NUMBER: builtins.int
    VIEW_THROUGH_LOOKBACK_WINDOW_DAYS_FIELD_NUMBER: builtins.int
    VALUE_SETTINGS_FIELD_NUMBER: builtins.int
    COUNTING_TYPE_FIELD_NUMBER: builtins.int
    ATTRIBUTION_MODEL_SETTINGS_FIELD_NUMBER: builtins.int
    TAG_SNIPPETS_FIELD_NUMBER: builtins.int
    PHONE_CALL_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    MOBILE_APP_VENDOR_FIELD_NUMBER: builtins.int
    FIREBASE_SETTINGS_FIELD_NUMBER: builtins.int
    THIRD_PARTY_APP_ANALYTICS_SETTINGS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    status: google.ads.google_ads.v5.proto.enums.conversion_action_status_pb2.ConversionActionStatusEnum.ConversionActionStatus.V = (
        ...
    )
    type: google.ads.google_ads.v5.proto.enums.conversion_action_type_pb2.ConversionActionTypeEnum.ConversionActionType.V = (
        ...
    )
    category: google.ads.google_ads.v5.proto.enums.conversion_action_category_pb2.ConversionActionCategoryEnum.ConversionActionCategory.V = (
        ...
    )
    owner_customer: typing.Text = ...
    include_in_conversions_metric: builtins.bool = ...
    click_through_lookback_window_days: builtins.int = ...
    view_through_lookback_window_days: builtins.int = ...
    counting_type: google.ads.google_ads.v5.proto.enums.conversion_action_counting_type_pb2.ConversionActionCountingTypeEnum.ConversionActionCountingType.V = (
        ...
    )
    phone_call_duration_seconds: builtins.int = ...
    app_id: typing.Text = ...
    mobile_app_vendor: google.ads.google_ads.v5.proto.enums.mobile_app_vendor_pb2.MobileAppVendorEnum.MobileAppVendor.V = (
        ...
    )
    @property
    def value_settings(self) -> global___ConversionAction.ValueSettings: ...
    @property
    def attribution_model_settings(
        self,
    ) -> global___ConversionAction.AttributionModelSettings: ...
    @property
    def tag_snippets(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v5.proto.common.tag_snippet_pb2.TagSnippet
    ]: ...
    @property
    def firebase_settings(self) -> global___ConversionAction.FirebaseSettings: ...
    @property
    def third_party_app_analytics_settings(
        self,
    ) -> global___ConversionAction.ThirdPartyAppAnalyticsSettings: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        status: google.ads.google_ads.v5.proto.enums.conversion_action_status_pb2.ConversionActionStatusEnum.ConversionActionStatus.V = ...,
        type: google.ads.google_ads.v5.proto.enums.conversion_action_type_pb2.ConversionActionTypeEnum.ConversionActionType.V = ...,
        category: google.ads.google_ads.v5.proto.enums.conversion_action_category_pb2.ConversionActionCategoryEnum.ConversionActionCategory.V = ...,
        owner_customer: typing.Text = ...,
        include_in_conversions_metric: builtins.bool = ...,
        click_through_lookback_window_days: builtins.int = ...,
        view_through_lookback_window_days: builtins.int = ...,
        value_settings: typing.Optional[global___ConversionAction.ValueSettings] = ...,
        counting_type: google.ads.google_ads.v5.proto.enums.conversion_action_counting_type_pb2.ConversionActionCountingTypeEnum.ConversionActionCountingType.V = ...,
        attribution_model_settings: typing.Optional[
            global___ConversionAction.AttributionModelSettings
        ] = ...,
        tag_snippets: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.common.tag_snippet_pb2.TagSnippet
            ]
        ] = ...,
        phone_call_duration_seconds: builtins.int = ...,
        app_id: typing.Text = ...,
        mobile_app_vendor: google.ads.google_ads.v5.proto.enums.mobile_app_vendor_pb2.MobileAppVendorEnum.MobileAppVendor.V = ...,
        firebase_settings: typing.Optional[
            global___ConversionAction.FirebaseSettings
        ] = ...,
        third_party_app_analytics_settings: typing.Optional[
            global___ConversionAction.ThirdPartyAppAnalyticsSettings
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_click_through_lookback_window_days",
            b"_click_through_lookback_window_days",
            "_id",
            b"_id",
            "_include_in_conversions_metric",
            b"_include_in_conversions_metric",
            "_name",
            b"_name",
            "_owner_customer",
            b"_owner_customer",
            "_phone_call_duration_seconds",
            b"_phone_call_duration_seconds",
            "_view_through_lookback_window_days",
            b"_view_through_lookback_window_days",
            "app_id",
            b"app_id",
            "attribution_model_settings",
            b"attribution_model_settings",
            "click_through_lookback_window_days",
            b"click_through_lookback_window_days",
            "firebase_settings",
            b"firebase_settings",
            "id",
            b"id",
            "include_in_conversions_metric",
            b"include_in_conversions_metric",
            "name",
            b"name",
            "owner_customer",
            b"owner_customer",
            "phone_call_duration_seconds",
            b"phone_call_duration_seconds",
            "third_party_app_analytics_settings",
            b"third_party_app_analytics_settings",
            "value_settings",
            b"value_settings",
            "view_through_lookback_window_days",
            b"view_through_lookback_window_days",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_app_id",
            b"_app_id",
            "_click_through_lookback_window_days",
            b"_click_through_lookback_window_days",
            "_id",
            b"_id",
            "_include_in_conversions_metric",
            b"_include_in_conversions_metric",
            "_name",
            b"_name",
            "_owner_customer",
            b"_owner_customer",
            "_phone_call_duration_seconds",
            b"_phone_call_duration_seconds",
            "_view_through_lookback_window_days",
            b"_view_through_lookback_window_days",
            "app_id",
            b"app_id",
            "attribution_model_settings",
            b"attribution_model_settings",
            "category",
            b"category",
            "click_through_lookback_window_days",
            b"click_through_lookback_window_days",
            "counting_type",
            b"counting_type",
            "firebase_settings",
            b"firebase_settings",
            "id",
            b"id",
            "include_in_conversions_metric",
            b"include_in_conversions_metric",
            "mobile_app_vendor",
            b"mobile_app_vendor",
            "name",
            b"name",
            "owner_customer",
            b"owner_customer",
            "phone_call_duration_seconds",
            b"phone_call_duration_seconds",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "tag_snippets",
            b"tag_snippets",
            "third_party_app_analytics_settings",
            b"third_party_app_analytics_settings",
            "type",
            b"type",
            "value_settings",
            b"value_settings",
            "view_through_lookback_window_days",
            b"view_through_lookback_window_days",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_app_id", b"_app_id"]
    ) -> typing_extensions.Literal["app_id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_click_through_lookback_window_days",
            b"_click_through_lookback_window_days",
        ],
    ) -> typing_extensions.Literal["click_through_lookback_window_days"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_include_in_conversions_metric", b"_include_in_conversions_metric"
        ],
    ) -> typing_extensions.Literal["include_in_conversions_metric"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_owner_customer", b"_owner_customer"],
    ) -> typing_extensions.Literal["owner_customer"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_phone_call_duration_seconds", b"_phone_call_duration_seconds"
        ],
    ) -> typing_extensions.Literal["phone_call_duration_seconds"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_view_through_lookback_window_days", b"_view_through_lookback_window_days"
        ],
    ) -> typing_extensions.Literal["view_through_lookback_window_days"]: ...

global___ConversionAction = ConversionAction



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OfflineUserDataJobStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OfflineUserDataJobStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OfflineUserDataJobStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(0)
        UNKNOWN = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(1)
        PENDING = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(2)
        RUNNING = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(3)
        SUCCESS = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(4)
        FAILED = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(5)
    class OfflineUserDataJobStatus(metaclass=_OfflineUserDataJobStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(0)
    UNKNOWN = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(1)
    PENDING = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(2)
    RUNNING = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(3)
    SUCCESS = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(4)
    FAILED = OfflineUserDataJobStatusEnum.OfflineUserDataJobStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___OfflineUserDataJobStatusEnum = OfflineUserDataJobStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdDestinationTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdDestinationType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdDestinationType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdDestinationTypeEnum.AdDestinationType.V(0)
        UNKNOWN = AdDestinationTypeEnum.AdDestinationType.V(1)
        NOT_APPLICABLE = AdDestinationTypeEnum.AdDestinationType.V(2)
        WEBSITE = AdDestinationTypeEnum.AdDestinationType.V(3)
        APP_DEEP_LINK = AdDestinationTypeEnum.AdDestinationType.V(4)
        APP_STORE = AdDestinationTypeEnum.AdDestinationType.V(5)
        PHONE_CALL = AdDestinationTypeEnum.AdDestinationType.V(6)
        MAP_DIRECTIONS = AdDestinationTypeEnum.AdDestinationType.V(7)
        LOCATION_LISTING = AdDestinationTypeEnum.AdDestinationType.V(8)
        MESSAGE = AdDestinationTypeEnum.AdDestinationType.V(9)
        LEAD_FORM = AdDestinationTypeEnum.AdDestinationType.V(10)
        YOUTUBE = AdDestinationTypeEnum.AdDestinationType.V(11)
        UNMODELED_FOR_CONVERSIONS = AdDestinationTypeEnum.AdDestinationType.V(12)
    class AdDestinationType(metaclass=_AdDestinationType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdDestinationTypeEnum.AdDestinationType.V(0)
    UNKNOWN = AdDestinationTypeEnum.AdDestinationType.V(1)
    NOT_APPLICABLE = AdDestinationTypeEnum.AdDestinationType.V(2)
    WEBSITE = AdDestinationTypeEnum.AdDestinationType.V(3)
    APP_DEEP_LINK = AdDestinationTypeEnum.AdDestinationType.V(4)
    APP_STORE = AdDestinationTypeEnum.AdDestinationType.V(5)
    PHONE_CALL = AdDestinationTypeEnum.AdDestinationType.V(6)
    MAP_DIRECTIONS = AdDestinationTypeEnum.AdDestinationType.V(7)
    LOCATION_LISTING = AdDestinationTypeEnum.AdDestinationType.V(8)
    MESSAGE = AdDestinationTypeEnum.AdDestinationType.V(9)
    LEAD_FORM = AdDestinationTypeEnum.AdDestinationType.V(10)
    YOUTUBE = AdDestinationTypeEnum.AdDestinationType.V(11)
    UNMODELED_FOR_CONVERSIONS = AdDestinationTypeEnum.AdDestinationType.V(12)
    def __init__(
        self,
    ) -> None: ...

global___AdDestinationTypeEnum = AdDestinationTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdGroupError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdGroupErrorEnum.AdGroupError.V(0)
        UNKNOWN = AdGroupErrorEnum.AdGroupError.V(1)
        DUPLICATE_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(2)
        INVALID_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(3)
        ADVERTISER_NOT_ON_CONTENT_NETWORK = AdGroupErrorEnum.AdGroupError.V(5)
        BID_TOO_BIG = AdGroupErrorEnum.AdGroupError.V(6)
        BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = AdGroupErrorEnum.AdGroupError.V(7)
        MISSING_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(8)
        ADGROUP_LABEL_DOES_NOT_EXIST = AdGroupErrorEnum.AdGroupError.V(9)
        ADGROUP_LABEL_ALREADY_EXISTS = AdGroupErrorEnum.AdGroupError.V(10)
        INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = AdGroupErrorEnum.AdGroupError.V(11)
        AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = (
            AdGroupErrorEnum.AdGroupError.V(12)
        )
        ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = (
            AdGroupErrorEnum.AdGroupError.V(13)
        )
        CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = (
            AdGroupErrorEnum.AdGroupError.V(14)
        )
        PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER = (
            AdGroupErrorEnum.AdGroupError.V(15)
        )
    class AdGroupError(metaclass=_AdGroupError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupErrorEnum.AdGroupError.V(0)
    UNKNOWN = AdGroupErrorEnum.AdGroupError.V(1)
    DUPLICATE_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(2)
    INVALID_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(3)
    ADVERTISER_NOT_ON_CONTENT_NETWORK = AdGroupErrorEnum.AdGroupError.V(5)
    BID_TOO_BIG = AdGroupErrorEnum.AdGroupError.V(6)
    BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH = AdGroupErrorEnum.AdGroupError.V(7)
    MISSING_ADGROUP_NAME = AdGroupErrorEnum.AdGroupError.V(8)
    ADGROUP_LABEL_DOES_NOT_EXIST = AdGroupErrorEnum.AdGroupError.V(9)
    ADGROUP_LABEL_ALREADY_EXISTS = AdGroupErrorEnum.AdGroupError.V(10)
    INVALID_CONTENT_BID_CRITERION_TYPE_GROUP = AdGroupErrorEnum.AdGroupError.V(11)
    AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE = (
        AdGroupErrorEnum.AdGroupError.V(12)
    )
    ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY = (
        AdGroupErrorEnum.AdGroupError.V(13)
    )
    CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING = (
        AdGroupErrorEnum.AdGroupError.V(14)
    )
    PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER = (
        AdGroupErrorEnum.AdGroupError.V(15)
    )
    def __init__(
        self,
    ) -> None: ...

global___AdGroupErrorEnum = AdGroupErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.product_bidding_category_level_pb2
import google.ads.google_ads.v6.proto.enums.product_bidding_category_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ProductBiddingCategoryConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_CONSTANT_PARENT_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    LOCALIZED_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    country_code: typing.Text = ...
    product_bidding_category_constant_parent: typing.Text = ...
    level: google.ads.google_ads.v6.proto.enums.product_bidding_category_level_pb2.ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V = (
        ...
    )
    status: google.ads.google_ads.v6.proto.enums.product_bidding_category_status_pb2.ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V = (
        ...
    )
    language_code: typing.Text = ...
    localized_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        country_code: typing.Text = ...,
        product_bidding_category_constant_parent: typing.Text = ...,
        level: google.ads.google_ads.v6.proto.enums.product_bidding_category_level_pb2.ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel.V = ...,
        status: google.ads.google_ads.v6.proto.enums.product_bidding_category_status_pb2.ProductBiddingCategoryStatusEnum.ProductBiddingCategoryStatus.V = ...,
        language_code: typing.Text = ...,
        localized_name: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_language_code",
            b"_language_code",
            "_localized_name",
            b"_localized_name",
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "language_code",
            b"language_code",
            "localized_name",
            b"localized_name",
            "product_bidding_category_constant_parent",
            b"product_bidding_category_constant_parent",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_country_code",
            b"_country_code",
            "_id",
            b"_id",
            "_language_code",
            b"_language_code",
            "_localized_name",
            b"_localized_name",
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "language_code",
            b"language_code",
            "level",
            b"level",
            "localized_name",
            b"localized_name",
            "product_bidding_category_constant_parent",
            b"product_bidding_category_constant_parent",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_country_code", b"_country_code"]
    ) -> typing_extensions.Literal["country_code"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_language_code", b"_language_code"],
    ) -> typing_extensions.Literal["language_code"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_localized_name", b"_localized_name"],
    ) -> typing_extensions.Literal["localized_name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_product_bidding_category_constant_parent",
            b"_product_bidding_category_constant_parent",
        ],
    ) -> typing_extensions.Literal["product_bidding_category_constant_parent"]: ...

global___ProductBiddingCategoryConstant = ProductBiddingCategoryConstant



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MinuteOfHourEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MinuteOfHour(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MinuteOfHour.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MinuteOfHourEnum.MinuteOfHour.V(0)
        UNKNOWN = MinuteOfHourEnum.MinuteOfHour.V(1)
        ZERO = MinuteOfHourEnum.MinuteOfHour.V(2)
        FIFTEEN = MinuteOfHourEnum.MinuteOfHour.V(3)
        THIRTY = MinuteOfHourEnum.MinuteOfHour.V(4)
        FORTY_FIVE = MinuteOfHourEnum.MinuteOfHour.V(5)
    class MinuteOfHour(metaclass=_MinuteOfHour):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MinuteOfHourEnum.MinuteOfHour.V(0)
    UNKNOWN = MinuteOfHourEnum.MinuteOfHour.V(1)
    ZERO = MinuteOfHourEnum.MinuteOfHour.V(2)
    FIFTEEN = MinuteOfHourEnum.MinuteOfHour.V(3)
    THIRTY = MinuteOfHourEnum.MinuteOfHour.V(4)
    FORTY_FIVE = MinuteOfHourEnum.MinuteOfHour.V(5)
    def __init__(
        self,
    ) -> None: ...

global___MinuteOfHourEnum = MinuteOfHourEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MessagePlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MessagePlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            MessagePlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(0)
        UNKNOWN = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(1)
        BUSINESS_NAME = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(2)
        COUNTRY_CODE = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(3)
        PHONE_NUMBER = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(4)
        MESSAGE_EXTENSION_TEXT = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(
            5
        )
        MESSAGE_TEXT = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(6)
    class MessagePlaceholderField(metaclass=_MessagePlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(0)
    UNKNOWN = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(1)
    BUSINESS_NAME = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(2)
    COUNTRY_CODE = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(3)
    PHONE_NUMBER = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(4)
    MESSAGE_EXTENSION_TEXT = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(5)
    MESSAGE_TEXT = MessagePlaceholderFieldEnum.MessagePlaceholderField.V(6)
    def __init__(
        self,
    ) -> None: ...

global___MessagePlaceholderFieldEnum = MessagePlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PaymentsAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PAYMENTS_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
    SECONDARY_PAYMENTS_PROFILE_ID_FIELD_NUMBER: builtins.int
    PAYING_MANAGER_CUSTOMER_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    @property
    def payments_account_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def currency_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def payments_profile_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def secondary_payments_profile_id(
        self,
    ) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def paying_manager_customer(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        payments_account_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        currency_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        payments_profile_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        secondary_payments_profile_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        paying_manager_customer: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "resource_name",
            b"resource_name",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> None: ...

global___PaymentsAccount = PaymentsAccount



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.matching_function_context_type_pb2
import google.ads.google_ads.v5.proto.enums.matching_function_operator_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MatchingFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FUNCTION_STRING_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    LEFT_OPERANDS_FIELD_NUMBER: builtins.int
    RIGHT_OPERANDS_FIELD_NUMBER: builtins.int
    operator: google.ads.google_ads.v5.proto.enums.matching_function_operator_pb2.MatchingFunctionOperatorEnum.MatchingFunctionOperator.V = (
        ...
    )
    @property
    def function_string(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def left_operands(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___Operand
    ]: ...
    @property
    def right_operands(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___Operand
    ]: ...
    def __init__(
        self,
        *,
        function_string: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        operator: google.ads.google_ads.v5.proto.enums.matching_function_operator_pb2.MatchingFunctionOperatorEnum.MatchingFunctionOperator.V = ...,
        left_operands: typing.Optional[typing.Iterable[global___Operand]] = ...,
        right_operands: typing.Optional[typing.Iterable[global___Operand]] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["function_string", b"function_string"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "function_string",
            b"function_string",
            "left_operands",
            b"left_operands",
            "operator",
            b"operator",
            "right_operands",
            b"right_operands",
        ],
    ) -> None: ...

global___MatchingFunction = MatchingFunction

class Operand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class ConstantOperand(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        STRING_VALUE_FIELD_NUMBER: builtins.int
        LONG_VALUE_FIELD_NUMBER: builtins.int
        BOOLEAN_VALUE_FIELD_NUMBER: builtins.int
        DOUBLE_VALUE_FIELD_NUMBER: builtins.int
        @property
        def string_value(self) -> google.protobuf.wrappers_pb2.StringValue: ...
        @property
        def long_value(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        @property
        def boolean_value(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
        @property
        def double_value(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
        def __init__(
            self,
            *,
            string_value: typing.Optional[
                google.protobuf.wrappers_pb2.StringValue
            ] = ...,
            long_value: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
            boolean_value: typing.Optional[
                google.protobuf.wrappers_pb2.BoolValue
            ] = ...,
            double_value: typing.Optional[
                google.protobuf.wrappers_pb2.DoubleValue
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "boolean_value",
                b"boolean_value",
                "constant_operand_value",
                b"constant_operand_value",
                "double_value",
                b"double_value",
                "long_value",
                b"long_value",
                "string_value",
                b"string_value",
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "boolean_value",
                b"boolean_value",
                "constant_operand_value",
                b"constant_operand_value",
                "double_value",
                b"double_value",
                "long_value",
                b"long_value",
                "string_value",
                b"string_value",
            ],
        ) -> None: ...
        def WhichOneof(
            self,
            oneof_group: typing_extensions.Literal[
                "constant_operand_value", b"constant_operand_value"
            ],
        ) -> typing_extensions.Literal[
            "string_value", "long_value", "boolean_value", "double_value"
        ]: ...
    class FeedAttributeOperand(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        FEED_ID_FIELD_NUMBER: builtins.int
        FEED_ATTRIBUTE_ID_FIELD_NUMBER: builtins.int
        @property
        def feed_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        @property
        def feed_attribute_id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
        def __init__(
            self,
            *,
            feed_id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
            feed_attribute_id: typing.Optional[
                google.protobuf.wrappers_pb2.Int64Value
            ] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "feed_attribute_id", b"feed_attribute_id", "feed_id", b"feed_id"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "feed_attribute_id", b"feed_attribute_id", "feed_id", b"feed_id"
            ],
        ) -> None: ...
    class FunctionOperand(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        MATCHING_FUNCTION_FIELD_NUMBER: builtins.int
        @property
        def matching_function(self) -> global___MatchingFunction: ...
        def __init__(
            self,
            *,
            matching_function: typing.Optional[global___MatchingFunction] = ...,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions.Literal[
                "matching_function", b"matching_function"
            ],
        ) -> builtins.bool: ...
        def ClearField(
            self,
            field_name: typing_extensions.Literal[
                "matching_function", b"matching_function"
            ],
        ) -> None: ...
    class RequestContextOperand(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        CONTEXT_TYPE_FIELD_NUMBER: builtins.int
        context_type: google.ads.google_ads.v5.proto.enums.matching_function_context_type_pb2.MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V = (
            ...
        )
        def __init__(
            self,
            *,
            context_type: google.ads.google_ads.v5.proto.enums.matching_function_context_type_pb2.MatchingFunctionContextTypeEnum.MatchingFunctionContextType.V = ...,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions.Literal["context_type", b"context_type"]
        ) -> None: ...
    CONSTANT_OPERAND_FIELD_NUMBER: builtins.int
    FEED_ATTRIBUTE_OPERAND_FIELD_NUMBER: builtins.int
    FUNCTION_OPERAND_FIELD_NUMBER: builtins.int
    REQUEST_CONTEXT_OPERAND_FIELD_NUMBER: builtins.int
    @property
    def constant_operand(self) -> global___Operand.ConstantOperand: ...
    @property
    def feed_attribute_operand(self) -> global___Operand.FeedAttributeOperand: ...
    @property
    def function_operand(self) -> global___Operand.FunctionOperand: ...
    @property
    def request_context_operand(self) -> global___Operand.RequestContextOperand: ...
    def __init__(
        self,
        *,
        constant_operand: typing.Optional[global___Operand.ConstantOperand] = ...,
        feed_attribute_operand: typing.Optional[
            global___Operand.FeedAttributeOperand
        ] = ...,
        function_operand: typing.Optional[global___Operand.FunctionOperand] = ...,
        request_context_operand: typing.Optional[
            global___Operand.RequestContextOperand
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "constant_operand",
            b"constant_operand",
            "feed_attribute_operand",
            b"feed_attribute_operand",
            "function_argument_operand",
            b"function_argument_operand",
            "function_operand",
            b"function_operand",
            "request_context_operand",
            b"request_context_operand",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "constant_operand",
            b"constant_operand",
            "feed_attribute_operand",
            b"feed_attribute_operand",
            "function_argument_operand",
            b"function_argument_operand",
            "function_operand",
            b"function_operand",
            "request_context_operand",
            b"request_context_operand",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "function_argument_operand", b"function_argument_operand"
        ],
    ) -> typing_extensions.Literal[
        "constant_operand",
        "feed_attribute_operand",
        "function_operand",
        "request_context_operand",
    ]: ...

global___Operand = Operand
